==> haskell-text-latin1-0.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-latin1
version: 0.3
id: text-latin1-0.3-JEcsemhHVZw6TQLW0QZTnO
key: text-latin1-0.3-JEcsemhHVZw6TQLW0QZTnO
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-latin1
synopsis: Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Ascii Text.Latin1
abi: e64b14759e5f0e3dc50352f7edbaea74
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-latin1-0.3
hs-libraries: HStext-latin1-0.3-JEcsemhHVZw6TQLW0QZTnO
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HwS3NhekiJcDT3x6QkJ9Xz
    data-checked-0.3-HVfY8aafhekBqF3684CsqD
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html: /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-latin1
version: 0.3
id: text-latin1-0.3-9VPHsWoLgvzJ6rNXX3I0m4
key: text-latin1-0.3-9VPHsWoLgvzJ6rNXX3I0m4
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-latin1
synopsis: Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Ascii Text.Latin1
abi: d7b3cd68b4a217ed53de7178b5e240a2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-latin1-0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-latin1-0.3
hs-libraries: HStext-latin1-0.3-9VPHsWoLgvzJ6rNXX3I0m4
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
    data-checked-0.3-HVfY8aafhekBqF3684CsqD
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html: /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
